diff --git a/src/password-store.sh b/src/password-store.sh
index c85cc33..50a943c 100755
--- a/src/password-store.sh
+++ b/src/password-store.sh
@@ -92,7 +92,9 @@ agent_check() {
 reencrypt_path() {
 	local prev_gpg_recipients="" gpg_keys="" current_keys="" index passfile
 	local groups="$($GPG --list-config --with-colons | grep "^cfg:group:.*")"
-	while read -r -d "" passfile; do
+	local -a files
+	populate_file_list "$1"
+	for passfile in "${files[@]}"; do
 		local passfile_dir="${passfile%/*}"
 		passfile_dir="${passfile_dir#$PREFIX}"
 		passfile_dir="${passfile_dir#/}"
@@ -118,7 +120,7 @@ reencrypt_path() {
 			mv "$passfile_temp" "$passfile" || rm -f "$passfile_temp"
 		fi
 		prev_gpg_recipients="${GPG_RECIPIENTS[*]}"
-	done < <(find "$1" -iname '*.gpg' -print0)
+	done
 }
 check_sneaky_paths() {
 	local path
@@ -126,6 +128,14 @@ check_sneaky_paths() {
 		[[ $path =~ /\.\.$ || $path =~ ^\.\./ || $path =~ /\.\./ || $path =~ ^\.\.$ ]] && die "Error: You've attempted to pass a sneaky path to pass. Go home."
 	done
 }
+populate_file_list () {
+	# This function will modify the global array "files".
+	local file
+	files=( )
+	while read -rd '' file; do
+		files+=( "$file" )
+	done < <(find "$1" -iname '*.gpg' -print0)
+}

 #
 # END helper functions
@@ -351,7 +361,9 @@ cmd_grep() {
 	[[ $# -ne 1 ]] && die "Usage: $PROGRAM $COMMAND search-string"
 	agent_check
 	local search="$1" passfile grepresults
-	while read -r -d "" passfile; do
+	local -a files=()
+	populate_file_list "$PREFIX"
+	for passfile in "${files[@]}"; do
 		grepresults="$($GPG -d "${GPG_OPTS[@]}" "$passfile" | grep --color=always "$search")"
 		[ $? -ne 0 ] && continue
 		passfile="${passfile%.gpg}"
@@ -360,7 +372,7 @@ cmd_grep() {
 		passfile="${passfile##*/}"
 		printf "\e[94m%s/\e[1m%s\e[0m:\n" "$passfile_dir" "$passfile"
 		echo "$grepresults"
-	done < <(find -L "$PREFIX" -iname '*.gpg' -print0)
+	done
 }

 cmd_insert() {
